package ro.test

import com.intellij.openapi.actionSystem.AnAction
import com.intellij.openapi.actionSystem.AnActionEvent

/**
 * Created by roroco on 4/6/15.
 */
class Plugin extends AnAction {

    @Override
    void actionPerformed(AnActionEvent e) {
        "notify-send $Calendar.instance".execute()
    }
}
